/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#ifndef ___FILESPACE_H___
#define ___FILESPACE_H___

typedef struct freelist {
	PN_FREELIST		f;
	unsigned int		fofs;
	struct freelist *	next;
} FREELIST;

unsigned int alloc_filespace(PDB *,PN_HEADER * h);
void free_filespace(PDB *,unsigned int);
void * get_file_record(unsigned int *,PDB *,short);
void * xx_read_filespace(PDB *,unsigned int,char * __file,int __line);
#define read_filespace(p,ofs)	xx_read_filespace((p),(ofs),__FILE__,__LINE__)
int write_filespace(PDB *,void *);
void flush_filespace(PDB * );

#endif

